<?php
/**
 * OOPでBBS (Step7)
 *
 * オブジェクト指向プログラミングで掲示板を作ってみる。
 * ブログでその作り方を晒すために書いたものです。
 * 詳しい事は当該記事を見てください。 
 *
 *
 *           
 * PHP version 5.3
 *
 * LICENSE : このソースはCreative Commons 表示 - 非営利 2.1 日本 Licenseです。
 *           改変は自由ですが営利目的で利用することは出来ません。
 *
 * @category  Step7
 * @package   OOPdeBBS
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 *
 */
 

/**
 * 掲示板の描画を行うクラス
 *
 * ViewはControllerに使役されるクラスです。
 * 掲示板の表示を受け持ちます。
 *
 * <step7>
 * 特に変更なし。
 * 
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   Creative Commons BY-NC http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 */
class View {
    
	//const TEMPLATE_DIRECTORY = 'template/'; //@deprecated 1.5 (step5)
    private $_templateDirectory; //テンプレートディレクトリ
    private $_templateName;      //テンプレートファイル名
	private $_tempateExtention;  //テンプレートの拡張子
    private $_systemMessage;     //システムメッセージ
    private $_logs;              //ログデータ
	protected $_userControll;      //ユーザー操作許可
    
    public function __construct($config)
    {
		$this->_templateDirectory = $config->get('template_directory') . DIRECTORY_SEPARATOR;
		$this->_templateExtention = '.' . $config->get('template_extention');
        $this->_templateName = '';
        $this->_systemMessage = array('type'=>'', 'text'=>'');
        $this->_logs = NULL;
		
		if($config->get('user_controll')==='1'){//ユーザーによる操作
			$this->_userControll = true;
		}
    }
    
     /**
     * テンプレート名のセッター
     * @param {string}  $name テンプレートファイル名
     * @return {}
     * @since 1.2 (step2)
     */
    public function setTemplateName($name)
    {
        $this->_templateName = $name . $this->_templateExtention;
    }
    
    /**
     * テンプレート名のゲッター
     * @return {string}　テンプレートファイル名
     * @since 1.2 (step2)
     */
    public function getTemplateName()
    {
       return  $this->_templateDirectory . $this->_templateName;
    }
    
    /**
     * システムメッセージのセッター
     * @param {NULL|string} $type メッセージのタイプ
     * @param {string} $text メッセージ文字列
     * @return {}
     * @since 1.2(step2)
     */
    public function setSystemMessage($type=NULL, $text)
    {
        $this->_systemMessage = array('type'=>$type, 'text'=>$text);
    }
    
    /**
     * エラーメッセージのセッター
     * $_systemMessageにセットする。
     * 
     * @param {string} $text メッセージ文字列
     * @return {}
     * @since 1.2(step2)
     * @deprecated 1.5 (step5)
     */
    //public function setErrorMessage($text)
    //{
    //    $this->_systemMessage = $text;
    //}
    
    /**
     * システムメッセージのゲッター
     * @return array|string メッセージ配列または文字列
     * @since Version 1.2 (step2)
     */
    public function getSystemMessage()
    {
        return $this->_systemMessage['text'];
    }
    
    /**
     * ログデータのセッター
     * @param {array} $log Logオブジェクトを入れた配列
     * @return {}
     * @since 1.4(Step4)
     */
     
    public function setLog($log)
    {
        $this->_logs = $log;
    }
    
    /**
     * ログデータのゲッター
     * @return {array} $log Logオブジェクトを入れた配列
     * @since 1.4(Step4)
     */
    public function getLog()
    {
        return $this->_logs;
    }
	
	/**
	 * トークンのセッター
	 * @param {string} $token 文字列
	 * @return {}
	 * @since 1.5(Step5)
	 */
	 
	public function setToken($token)
	{
		$this->_token = $token;
	}
	
	/**
	 * トークンのゲッター
	 * @param {string} $token 文字列
	 * @return
	 * @since 1.5(Step5)
	 */
	 
	public function getToken()
	{
		return $this->_token;
	}
	
    /**
     * 画面に表示する
     * @return
     * @since 1.0 (step1)
     */
    public function display()
    {
        $class = empty($this->_systemMessage['type']) ? '' : ' ' . $this->_systemMessage['type'];
        $message = $this->getSystemMessage();
       
        if(isset($message)){
            if( is_array($message) ){
               $message = implode('<br />', $message);
            }
            
            $message = '<p class="message' . $class . '">' . $message . '</p>';
        }
        
        $logdata = $this->getLog();
		
		$token = $this->getToken();
        
        include($this->getTemplateName());
    }
}

?>